import {
  select, 
  json, 
  geoPath,
  geoCentroid,
  geoAlbersUsa,
  zoom,
  event,
  scaleSqrt,
  max,
} from 'd3';

import { feature, merge } from 'topojson';
import { loadAndProcessData } from './loadAndProcessData';
import { usMap } from './usMap';
import { timeSlider } from './timeSlider';

const svg = select('svg');
const usMapg = svg.append('g');
const timeSliderG = svg.append('g');

const width = +svg.attr('width');
const height = +svg.attr('height');


let data;
let date;
let dates;
let sizeScale = null;
let selection;
let selectedYear = 0; 

const setSelectedYear = year => {
  selectedYear = year;
  render();
};
const stateMap = geoAlbersUsa();
const pathGenerator = map => geoPath().projection(map);
const radiusValue = d => d.properties['TotalVolume'];

loadAndProcessData().then(props => {  
  data = props[0];
  dates = props[1];
  sizeScale = scaleSqrt()
    .domain([0, max(data.features, radiusValue)])
    .range([0, 4]);
  
  render(data,dates);
});


const render = () => { 
  usMapg.call(usMap,{
    pathGenerator,
    stateMap,
    data,
    sizeScale,
    radiusValue,
    svg
  });
  
  svg.append("g")
    .attr("class","slider")
    .selectAll('rect').data([null])
    .enter().append('rect')
    .attr('x',105)
    .attr('y',520)
    .attr('width',width-105-105)
    .attr('height',height-520-40)
    .attr('fill','none')
    .attr('stroke','black')
    .attr('stroke-width','3')
  
    
  timeSliderG.call(timeSlider, {
    title: 'Select Week of 2017',
    xValue: d => d,
    xAxisLabel: 'Time',
    margin: {
      top: 520,
      right: 105,
      bottom: 40,
      left: 105
    },
    width,
    height,
    dates,
    selectedYear,
    setSelectedYear
  });
  
 
};     



