import {
  select,
  csv,
  scaleLinear,
  scaleOrdinal,
  extent,
  axisLeft,
  axisBottom,
  line,
  curveBasis,
  nest,
  schemeCategory10,
  descending,
  format,
  mouse
} from 'd3';
import {
  parseYear
} from './loadAndProcessData';

export const timeSlider = (selection, props) => {
  const {
    title,
    xValue,
    xAxisLabel,
    margin,
    width,
    height,
    dates,
    selectedYear,
    setSelectedYear
  } = props;

  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const xScale = scaleLinear()
    .domain([0,dates.length-1])
    .range([0, innerWidth]);  
  
   
  
  const g = selection.selectAll('.container').data([null]);
  const gEnter = g.enter()
    .append('g')
      .attr('class', 'container');
  gEnter.merge(g)
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
    
  const xAxisGEnter = gEnter
    .append('g')
      .attr('class', 'x-axis');
  const xAxisG = g.select('.x-axis');
  xAxisGEnter
    .merge(xAxisG)
      .call(xAxis)
      .attr('transform', `translate(0,${innerHeight})`)
      .select('.domain').remove();
  
  xAxisGEnter
    .append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('fill', 'black')
    .merge(xAxisG.select('.axis-label'))
      .attr('x', innerWidth / 2)
      .text(xAxisLabel);
  
  
  let selectedIndex = selectedYear;
  gEnter
    .append('line')
      .attr('class', 'selected-year-line')
      .attr('y1', 0)
    .merge(g.select('.selected-year-line'))
      .attr('x1', xScale(selectedIndex))
      .attr('x2', xScale(selectedIndex))
      .attr('y2', innerHeight);
  
  gEnter
    .append('text')
      .attr('class', 'title')
      .attr('y', -10)
    .merge(g.select('.title'))
      .text(title);
  
  gEnter
    .append('rect')
      .attr('class', 'mouse-interceptor')
      .attr('fill', 'none')
      .attr('pointer-events', 'all')
    .merge(g.select('.mouse-interceptor'))
      .attr('width', innerWidth)
      .attr('height', innerHeight)
      .on('mousemove', function() {
        const x = mouse(this)[0];
        const hoveredDate = xScale.invert(x);
        const usedDate = Math.floor(hoveredDate);
        setSelectedYear(hoveredDate);
        
      });
};